@@ -1,11 +1,12 @@
 import collections
-import json
 import glob
+import json
 import logging
 import os
 from logging import Logger
 from pathlib import Path
 from typing import Dict, Any, List, Tuple, Optional, Union, cast
+from urllib.parse import parse_qs
 
 import dictdiffer  # type: ignore
 from requests import put, Response
@@ -22,8 +23,8 @@ from mockserver_client.exceptions.mock_server_json_content_mismatch_exception im
 from mockserver_client.exceptions.mock_server_request_not_found_exception import (
     MockServerRequestNotFoundException,
 )
-from ._timing import _Timing
 from ._time import _Time
+from ._timing import _Timing
 from .mockserver_verify_exception import MockServerVerifyException
 
 
@@ -182,8 +183,11 @@ class MockServerFriendlyClient(object):
             found_expectation: bool = False
             try:
                 for recorded_request in recorded_requests:
+                    # first try to match on both request url AND body
                     if "method" in expected_request and self.does_request_match(
-                        request1=expected_request, request2=recorded_request
+                        request1=expected_request,
+                        request2=recorded_request,
+                        check_body=True,
                     ):
                         found_expectation = True
                         # remove request from unmatched_requests
@@ -191,7 +195,7 @@ class MockServerFriendlyClient(object):
                             r
                             for r in unmatched_requests
                             if self.does_request_match(
-                                request1=r, request2=recorded_request
+                                request1=r, request2=recorded_request, check_body=True
                             )
                         ]
                         if len(unmatched_request_list) > 0:
@@ -203,6 +207,36 @@ class MockServerFriendlyClient(object):
                             expected_body = expected_request["body"]["json"]
                             actual_body = recorded_request["body"]["json"]
                             self.compare_request_bodies(actual_body, expected_body)
+                    # now compare using just the request url
+                    elif "method" in expected_request and self.does_request_match(
+                        request1=expected_request,
+                        request2=recorded_request,
+                        check_body=False,
+                    ):
+                        found_expectation = True
+                        # remove request from unmatched_requests
+                        unmatched_request_list = [
+                            r
+                            for r in unmatched_requests
+                            if self.does_request_match(
+                                request1=r, request2=recorded_request, check_body=False
+                            )
+                        ]
+                        if (
+                            "body" in expected_request
+                            and "json" in expected_request["body"]
+                        ):
+                            expected_body = expected_request["body"]["json"]
+                            actual_body = recorded_request["body"]["json"]
+                            if len(unmatched_request_list) > 0:
+                                unmatched_requests.remove(unmatched_request_list[0])
+                            self.compare_request_bodies(actual_body, expected_body)
+                        elif "body" in expected_request:
+                            expected_body = expected_request["body"]
+                            actual_body = recorded_request["body"]
+                            if len(unmatched_request_list) > 0:
+                                unmatched_requests.remove(unmatched_request_list[0])
+                            self.compare_request_bodies(actual_body, expected_body)
 
             except MockServerJsonContentMismatchException as e:
                 exceptions.append(e)
@@ -241,7 +275,9 @@ class MockServerFriendlyClient(object):
         return exceptions
 
     @staticmethod
-    def does_request_match(request1: Dict[str, Any], request2: Dict[str, Any]) -> bool:
+    def does_request_match(
+        request1: Dict[str, Any], request2: Dict[str, Any], check_body: bool
+    ) -> bool:
         return (
             request1["method"] == request2["method"]
             and request1["path"] == request2["path"]
@@ -254,11 +290,19 @@ class MockServerFriendlyClient(object):
             and MockServerFriendlyClient.does_id_in_request_match(
                 request1=request1, request2=request2
             )
-            and MockServerFriendlyClient.does_request_body_match(
-                request1=request1, request2=request2
+            and (
+                not check_body
+                or MockServerFriendlyClient.does_request_body_match(
+                    request1=request1, request2=request2
+                )
             )
         )
 
+    @staticmethod
+    def convert_query_parameters_to_dict(query: str) -> Dict[str, str]:
+        params: Dict[str, List[str]] = parse_qs(query)
+        return {k: v[0] for k, v in params.items()}
+
     @staticmethod
     def does_request_body_match(
         request1: Dict[str, Any], request2: Dict[str, Any]
@@ -272,23 +316,27 @@ class MockServerFriendlyClient(object):
         body1 = request1["body"]
         body2 = request2["body"]
         if "json" in body1 and "json" in body2:
-            return True if body1["json"] == body2["json"] else False
+            json1 = body1["json"]
+            if isinstance(json1, str):
+                json1 = json.loads(json1)
+            json2 = body2["json"]
+            if isinstance(json2, str):
+                json2 = json.loads(json2)
+            return True if json1 == json2 else False
         if "string" in body1 and request1["headers"]["Content-Type"] == [
             "application/x-www-form-urlencoded"
         ]:
             # mockserver stores x-form-url
             body1 = body1["string"]
             if isinstance(body1, str):
-                body1 = body1.split("&")
-                body1 = {i.split("=")[0]: i.split("=")[1] for i in body1}
+                body1 = MockServerFriendlyClient.convert_query_parameters_to_dict(body1)
         if "string" in body2 and request2["headers"]["Content-Type"] == [
             "application/x-www-form-urlencoded"
         ]:
             # mockserver stores x-form-url
             body2 = body2["string"]
             if isinstance(body2, str):
-                body2 = body2.split("&")
-                body2 = {i.split("=")[0]: i.split("=")[1] for i in body2}
+                body2 = MockServerFriendlyClient.convert_query_parameters_to_dict(body2)
         return True if body1 == body2 else False
 
     @staticmethod
